package com.lostinsoftware.ws.client;

import static org.junit.Assert.assertNotNull;

import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;

import com.lostinsoftware.ws.types.GetCitiesByCountry;
import com.lostinsoftware.ws.types.GetCitiesByCountryResponse;
import com.lostinsoftware.ws.types.GetWeather;
import com.lostinsoftware.ws.types.GetWeatherResponse;

import org.junit.Ignore;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.ws.client.core.WebServiceTemplate;
import org.springframework.ws.soap.client.core.SoapActionCallback;
import org.w3c.dom.Document;
import org.w3c.dom.Element;


@ContextConfiguration
@RunWith(SpringJUnit4ClassRunner.class)
public class WebServiceTest {
  
  @Autowired WebServiceTemplate webServiceTemplate;
  
  static final String NAMESPACE_URI = "http://www.webserviceX.NET";
  
  @Ignore
  @Test
  public void testWebServiceGetWeatherWithJAXB() throws Exception {   
    GetWeather request = new GetWeather();
    request.setCityName("Madrid");
    request.setCountryName("Spain");
    GetWeatherResponse response =
        (GetWeatherResponse) webServiceTemplate.marshalSendAndReceive(request,
            new SoapActionCallback("http://www.webserviceX.NET/GetWeather"));
    
    assertNotNull(response);
    System.out.println(response.getGetWeatherResult());
  }
  
  @Ignore 
  @Test
  public void testWebServiceGetCitiesByCountryWithJAXB() throws Exception {   
    GetCitiesByCountry request = new GetCitiesByCountry();
    request.setCountryName("Spain");
    GetCitiesByCountryResponse response =
        (GetCitiesByCountryResponse) webServiceTemplate.marshalSendAndReceive(request,
            new SoapActionCallback("http://www.webserviceX.NET/GetCitiesByCountry"));
    
    assertNotNull(response);
    System.out.println(response.getGetCitiesByCountryResult());
  }

  // @Ignore
  @Test
  public void testWebServiceGetWeatherWithXml() throws Exception {   
    Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
    Element requestElement = document.createElementNS(NAMESPACE_URI, "GetWeather");
    Element cityName = document.createElement("CityName");
    cityName.setTextContent("Madrid");
    requestElement.appendChild(cityName);
    Element countryName = document.createElement("CountryName");
    countryName.setTextContent("Spain");
    requestElement.appendChild(countryName);
    DOMSource source = new DOMSource(requestElement);
    DOMResult result = new DOMResult();
    webServiceTemplate.sendSourceAndReceiveToResult(source,  
            new SoapActionCallback("http://www.webserviceX.NET/GetWeather"),
            result);
    
    Element responseElement = (Element) result.getNode().getFirstChild();
    
    assertNotNull(responseElement);
  }

  @Ignore
  @Test
  public void testWebServiceGetCitiesByCountryWithXml() throws Exception {
    Document document = DocumentBuilderFactory.newInstance().newDocumentBuilder().newDocument();
    Element requestElement = document.createElementNS(NAMESPACE_URI, "GetCitiesByCountry");
    Element countryName = document.createElement("CountryName");
    countryName.setTextContent("Spain");
    requestElement.appendChild(countryName);
    DOMSource source = new DOMSource(requestElement);
    DOMResult result = new DOMResult();
    webServiceTemplate.sendSourceAndReceiveToResult(source,  
        new SoapActionCallback("http://www.webserviceX.NET/GetCitiesByCountry"),
        result);
    Element responseElement = (Element) result.getNode().getFirstChild();
    
    assertNotNull(responseElement);
    
  }

}
